@@ -1,6 +1,9 @@
 from dataclasses import (
     dataclass,
 )
+from deprecated import (
+    deprecated,
+)
 from fa_purity import (
     PureIter,
 )
@@ -324,7 +327,7 @@ class TableClient:
             dynamic_query(stm, FrozenDict(identifiers)), None
         )
 
-    def append(self, source: TableId, target: TableId) -> Cmd[None]:
+    def move_data(self, source: TableId, target: TableId) -> Cmd[None]:
         stm = """
             ALTER TABLE {target_schema}.{target_table}
             APPEND FROM {source_schema}.{source_table}
@@ -339,8 +342,16 @@ class TableClient:
             dynamic_query(stm, FrozenDict(identifiers)), None
         )
 
+    @deprecated(reason="Renamed method, use 'move_data' instead")  # type: ignore[misc]
+    def append(self, source: TableId, target: TableId) -> Cmd[None]:
+        """
+        This method moves data from source to target.
+        After the operation source will be empty.
+        """
+        return self.move_data(source, target)
+
     def move(self, source: TableId, target: TableId) -> Cmd[None]:
-        return self.append(source, target) + self.delete_cascade(source)
+        return self.move_data(source, target) + self.delete_cascade(source)
 
     def overwrite(self, source: TableId, target: TableId) -> Cmd[None]:
         nothing = Cmd.from_cmd(lambda: None)
